==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/ja.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "タスク",
    "Due yesterday" : "昨日まで",
    "Due today" : "今日まで",
    "Due tomorrow" : "明日まで",
    "Due on" : "期日",
    "Started yesterday" : "昨日開始",
    "Starts today" : "今日開始",
    "Starts tomorrow" : "明日開始",
    "Started on" : "開始",
    "Starts on" : "開始",
    "[Remind me yesterday at ]HH:mm" : "[昨日の通知時刻]HH:mm",
    "[Remind me today at ]HH:mm" : "[今日の通知時刻]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[明日の通知時刻]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "YYYY/MM/DD[の]HH:mm[に通知]",
    "Yesterday" : "昨日",
    "Today" : "今日",
    "Tomorrow" : "明日",
    "in %s" : "%s で",
    "%s ago" : "%s前",
    "seconds" : "秒",
    "a minute" : "1分",
    "%d minutes" : "%d分",
    "an hour" : "1時間",
    "%d hours" : "%d時間",
    "a day" : "1日",
    "%d days" : "%d日",
    "a month" : "1ヶ月",
    "%d months" : "%dヶ月",
    "a year" : "1年",
    "%d years" : "%d年",
    "week" : "週",
    "weeks" : "週",
    "day" : "日",
    "days" : "日",
    "hour" : "時間",
    "hours" : "時間",
    "minute" : "分",
    "minutes" : "分",
    "second" : "２週目",
    "before beginning" : "開始前",
    "after beginning" : "開始後",
    "before end" : "終了前",
    "after end" : "終了後",
    "Comment" : "コメント",
    "Add a comment" : "コメントを追加",
    "This will delete the Calendar \"%s\" and all of its entries." : "カレンダー \"%s\"とすべてのエントリが削除されます",
    "The name \"%s\" is already used." : "名前 \"%s\" はすでに使われています。",
    "An empty name is not allowed." : "件名を入力してください。",
    "Hidden" : "隠す",
    "Visible" : "表示する",
    "Automatic" : "自動",
    "Sunday" : "日",
    "Monday" : "月",
    "Tuesday" : "火",
    "Wednesday" : "水",
    "Thursday" : "木",
    "Friday" : "金",
    "Saturday" : "土",
    "Add an important item in \"%s\"..." : "重要なアイテムを \"%s\" に追加...",
    "Add an item due today in \"%s\"..." : "今日期限のアイテムを \"%s\" に追加...",
    "Add an item in \"%s\"..." : "アイテムを \"%s\" に追加...",
    "Add a current item in \"%s\"..." : "現在のアイテムを \"%s\" に追加...",
    "Add a subtask to \"%s\"..." : "サブタスクを \"%s\" に追加...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["完了済みタスク %n"],
    "Hours" : "時間",
    "Minutes" : "分",
    "Set due date" : "期限を設定",
    "%s %% completed" : "%s %% 完了",
    "priority %s: " : "優先度 %s:",
    "high" : "高い",
    "medium" : "中間",
    "low" : "低い",
    "no priority assigned" : "優先度未割り当て",
    "Remind me" : "リマインド",
    "at the end" : "終了時",
    "at the beginning" : "開始時",
    "Set start date" : "開始日を設定",
    "{calendar} shared by {owner}" : "{owner} が共有中の{calendar} ",
    "Unnamed" : "名称未設定",
    "Important" : "重要",
    "Week" : "週",
    "All" : "すべて",
    "Current" : "現在",
    "Completed" : "完了",
    "Delete" : "削除",
    "Cancel" : "キャンセル",
    "Edit" : "編集",
    "Link" : "リンク",
    "Download" : "ダウンロード",
    "Save" : "保存",
    "Add List..." : "リストを追加...",
    "New List" : "新規リスト",
    "Settings" : "設定",
    "Start of week" : "週の初め",
    "Visibility of Smart Collections" : "スマートコレクションの表示",
    "Change sort order" : "並び順を変更",
    "Default" : "デフォルト",
    "Due date" : "期限",
    "Start date" : "開始日",
    "Priority" : "優先度",
    "Alphabetically" : "アルファベット順",
    "Manually" : "手動",
    "Load remaining completed tasks." : "残りの完了済みタスクをロード",
    "All day" : "終日",
    "(New category)" : "(新しいカテゴリ)",
    "Select categories..." : "カテゴリーの選択...",
    "Loading the task..." : "タスクの読み込み中...",
    "Task not found!" : "タスクがありません！",
    "add a subtask to" : "サブタスクを次に追加"
},
"nplurals=1; plural=0;");

==> nextcloud-app-tasks-0.9.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/ja.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "タスク",
    "Due yesterday" : "昨日まで",
    "Due today" : "今日まで",
    "Due tomorrow" : "明日まで",
    "Due on" : "期日",
    "Started yesterday" : "昨日開始",
    "Starts today" : "今日開始",
    "Starts tomorrow" : "明日開始",
    "Started on" : "開始",
    "Starts on" : "開始",
    "[Remind me yesterday at ]HH:mm" : "[昨日の通知時刻]HH:mm",
    "[Remind me today at ]HH:mm" : "[今日の通知時刻]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[明日の通知時刻]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "YYYY/MM/DD[の]HH:mm[に通知]",
    "Yesterday" : "昨日",
    "Today" : "今日",
    "Tomorrow" : "明日",
    "in %s" : "%s で",
    "%s ago" : "%s前",
    "seconds" : "秒",
    "a minute" : "1分",
    "%d minutes" : "%d分",
    "an hour" : "1時間",
    "%d hours" : "%d時間",
    "a day" : "1日",
    "%d days" : "%d日",
    "a month" : "1ヶ月",
    "%d months" : "%dヶ月",
    "a year" : "1年",
    "%d years" : "%d年",
    "week" : "週",
    "weeks" : "週",
    "day" : "日",
    "days" : "日",
    "hour" : "時間",
    "hours" : "時間",
    "minute" : "分",
    "minutes" : "分",
    "second" : "２週目",
    "before beginning" : "開始前",
    "after beginning" : "開始後",
    "before end" : "終了前",
    "after end" : "終了後",
    "Comment" : "コメント",
    "Add a comment" : "コメントを追加",
    "This will delete the Calendar \"%s\" and all of its entries." : "カレンダー \"%s\"とすべてのエントリが削除されます",
    "The name \"%s\" is already used." : "名前 \"%s\" はすでに使われています。",
    "An empty name is not allowed." : "件名を入力してください。",
    "Hidden" : "隠す",
    "Visible" : "表示する",
    "Automatic" : "自動",
    "Sunday" : "日",
    "Monday" : "月",
    "Tuesday" : "火",
    "Wednesday" : "水",
    "Thursday" : "木",
    "Friday" : "金",
    "Saturday" : "土",
    "Add an important item in \"%s\"..." : "重要なアイテムを \"%s\" に追加...",
    "Add an item due today in \"%s\"..." : "今日期限のアイテムを \"%s\" に追加...",
    "Add an item in \"%s\"..." : "アイテムを \"%s\" に追加...",
    "Add a current item in \"%s\"..." : "現在のアイテムを \"%s\" に追加...",
    "Add a subtask to \"%s\"..." : "サブタスクを \"%s\" に追加...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["完了済みタスク %n"],
    "Hours" : "時間",
    "Minutes" : "分",
    "Set due date" : "期限を設定",
    "%s %% completed" : "%s %% 完了",
    "priority %s: " : "優先度 %s:",
    "high" : "高い",
    "medium" : "中間",
    "low" : "低い",
    "no priority assigned" : "優先度未割り当て",
    "Remind me" : "リマインド",
    "at the end" : "終了時",
    "at the beginning" : "開始時",
    "Set start date" : "開始日を設定",
    "{calendar} shared by {owner}" : "{owner} が共有中の{calendar} ",
    "Unnamed" : "名称未設定",
    "Important" : "重要",
    "Week" : "週",
    "All" : "すべて",
    "Current" : "現在",
    "Completed" : "完了",
    "Delete" : "削除",
    "Cancel" : "キャンセル",
    "Edit" : "編集",
    "Link" : "リンク",
    "Download" : "ダウンロード",
    "Save" : "保存",
    "Add List..." : "リストを追加...",
    "New List" : "新規リスト",
    "Settings" : "設定",
    "Start of week" : "週の初め",
    "Visibility of Smart Collections" : "スマートコレクションの表示",
    "Change sort order" : "並び順を変更",
    "Default" : "デフォルト",
    "Due date" : "期限",
    "Start date" : "開始日",
    "Priority" : "優先度",
    "Alphabetically" : "アルファベット順",
    "Manually" : "手動",
    "Load remaining completed tasks." : "残りの完了済みタスクをロード",
    "Task is completed" : "タスク完了",
    "All day" : "終日",
    "(New category)" : "(新しいカテゴリ)",
    "Select categories..." : "カテゴリーの選択...",
    "Loading the task..." : "タスクの読み込み中...",
    "Task not found!" : "タスクがありません！",
    "add a subtask to" : "サブタスクを次に追加",
    "Toggle subtasks" : "サブタスクをオン・オフ",
    "Toggle completed subtasks" : "完了のサブタスクをオン・オフ"
},
"nplurals=1; plural=0;");
